summaryrefslogtreecommitdiffstats
path: root/kword/KWPage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWPage.h')
-rw-r--r--kword/KWPage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kword/KWPage.h b/kword/KWPage.h
index b30a2ff9..44bffc2a 100644
--- a/kword/KWPage.h
+++ b/kword/KWPage.h
@@ -112,10 +112,10 @@ public:
private:
/** private constructor, only for our friends
* @param tqparent the KWPageManager that we belong to.
* @param pageNum the number of the page as the user will see it.
*/
- KWPage(KWPageManager *tqparent, int pageNum);
+ KWPage(KWPageManager *parent, int pageNum);
int m_pageNum;
PageSideEnum m_pageSide;
KoPageLayout m_pageLayout;
@@ -112,10 +112,10 @@ public:
private:
/** private constructor, only for our friends
- * @param tqparent the KWPageManager that we belong to.
+ * @param parent the KWPageManager that we belong to.
* @param pageNum the number of the page as the user will see it.
*/